@@ -7,13 +7,6 @@ import (
 	"testing"
 	"time"
 
-	fakeoperatorclient "github.com/open-cluster-management/api/client/operator/clientset/versioned/fake"
-	operatorinformers "github.com/open-cluster-management/api/client/operator/informers/externalversions"
-	fakeworkclient "github.com/open-cluster-management/api/client/work/clientset/versioned/fake"
-	opratorapiv1 "github.com/open-cluster-management/api/operator/v1"
-	workapiv1 "github.com/open-cluster-management/api/work/v1"
-	"github.com/open-cluster-management/registration-operator/pkg/helpers"
-	testinghelper "github.com/open-cluster-management/registration-operator/pkg/helpers/testing"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	fakeapiextensions "k8s.io/apiextensions-apiserver/pkg/client/clientset/clientset/fake"
@@ -28,6 +21,13 @@ import (
 	"k8s.io/client-go/tools/cache"
 	clientcmdapi "k8s.io/client-go/tools/clientcmd/api"
 	clientcmdlatest "k8s.io/client-go/tools/clientcmd/api/latest"
+	fakeoperatorclient "open-cluster-management.io/api/client/operator/clientset/versioned/fake"
+	operatorinformers "open-cluster-management.io/api/client/operator/informers/externalversions"
+	fakeworkclient "open-cluster-management.io/api/client/work/clientset/versioned/fake"
+	opratorapiv1 "open-cluster-management.io/api/operator/v1"
+	workapiv1 "open-cluster-management.io/api/work/v1"
+	"open-cluster-management.io/registration-operator/pkg/helpers"
+	testinghelper "open-cluster-management.io/registration-operator/pkg/helpers/testing"
 )
 
 type testController struct {
@@ -277,8 +277,8 @@ func TestSyncDeploy(t *testing.T) {
 	}
 
 	// Check if resources are created as expected
-	if len(createObjects) != 11 {
-		t.Errorf("Expect 11 objects created in the sync loop, actual %d", len(createObjects))
+	if len(createObjects) != 12 {
+		t.Errorf("Expect 12 objects created in the sync loop, actual %d", len(createObjects))
 	}
 	for _, object := range createObjects {
 		ensureObject(t, object, klusterlet)
@@ -338,8 +338,8 @@ func TestSyncDelete(t *testing.T) {
 		}
 	}
 
-	if len(deleteActions) != 13 {
-		t.Errorf("Expected 13 delete actions, but got %d", len(deleteActions))
+	if len(deleteActions) != 14 {
+		t.Errorf("Expected 14 delete actions, but got %d", len(deleteActions))
 	}
 
 	deleteCRDActions := []clienttesting.DeleteActionImpl{}
@@ -551,8 +551,8 @@ func TestDeployOnKube111(t *testing.T) {
 	}
 
 	// Check if resources are created as expected
-	if len(createObjects) != 13 {
-		t.Errorf("Expect 13 objects created in the sync loop, actual %d", len(createObjects))
+	if len(createObjects) != 14 {
+		t.Errorf("Expect 14 objects created in the sync loop, actual %d", len(createObjects))
 	}
 	for _, object := range createObjects {
 		ensureObject(t, object, klusterlet)
@@ -588,8 +588,8 @@ func TestDeployOnKube111(t *testing.T) {
 		}
 	}
 
-	if len(deleteActions) != 15 {
-		t.Errorf("Expected 15 delete actions, but got %d", len(kubeActions))
+	if len(deleteActions) != 16 {
+		t.Errorf("Expected 16 delete actions, but got %d", len(kubeActions))
 	}
 }
 
